package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````#``@````!```7L````#0``*9L<``0!P`T`"``
M"P`H`!\`'@````8````T````-````#0```%@```!8`````0````$`````P``
M`90```&4```!E`````T````-````!`````%P```#```!R````<@```'(````
M&````!@````$````"'````````'@```!X````>`````8````&`````0````$
M`````0``````````````````FH0``)J$````!0`!```````!``"?^``!G_@`
M`9_X```!Y```$A@````&``$```````(```(<```"'````AP```%0```!4```
M``0````$````!````:0```&D```!I````"`````@````!`````0````$```!
M^````?@```'X````)````"0````$````!&1TY5(``)_X``&?^``!G_@````(
M````"`````0````!``````````````````````````````````````````0O
M;&EB+VQD+G-O+C$`````````!````!`````!1TY5```````````#`````@``
M```````````@`@$!``4`````````````````````L@`!]@``````````````
M`````````B`P````!````!0````#1TY5``,LM.7UC1`05[:Z:1!:BS`YYCHG
M`````0```!P````!```!Y@````$```'Q`````0```?L````!```"2@````$`
M``.L`````0```\8````,```4<`````T``%J@````&0`!G_@````;````!```
M`!H``9_\````'`````0````$```#;`````4```U\````!@``!JP````*```%
M00````L````0<```-0`!G80````5``````````,``:!`````$0``%$@````2
M````*````!,````(<````0````%P```%`````G````8`````<```"@```!QP
M```1````;7```!(````><```$P```",````>````"&____L(```!;____@``
M$YAO____`````V____```!*^````````````````````````````````````
M````````````````````````````````80```&T````````````````````K
M```````````````R```````````````H````3@````````!(````3P````X`
M````````5P```!D````#````+0````D````1````/0```#``````````````
M`%@````5````)P``````````````(@```!P````^```````````````6````
M(0`````````V`````````#0`````````1P```!0````2````)0````````!J
M````&@````````!&````50``````````````&````$D````Z````10``````
M````````8`````````!2`````````"```````````````&0````F````*0``
M`"X```!$````*@```````````````@````L```!`````9P```!L````0````
M-0`````````C````'P``````````````$P```!<`````````/P```!X```!"
M````)````#$````[`````````````````````````````````````````&8`
M``````````````````!H````````````````````40```&4````*````#0``
M````````````0P````0`````````````````````````7@```%H`````````
M````````````````70```#<````\`````````#,```!+````+P```!T`````
M````+```````````````7P```&P```!C````4````#D```!!````2@``````
M```X````4P``````````````8@```$T````````````````````/````````
M``@``````````````&$````,````3`````````!I`````````%L`````````
M`````%D`````````````````````````5````%8`````````````````````
M``````````````!<````:P``````````````!0````````````````````<`
M``````````````````````````````8`````````````````````````````
M```````````````````````````4<``````#```-```#Y```5K0````($@``
M#@``!*P``#<H````&!(```X````!`````0`````3`/_Q```$TP`!H```````
M(0``%0```Z(``````````!$```````0Z```_-````%02```.```$H```520`
M``#,$@``#@``!+T``:'<`````!```!@```/N``!:H``````2```0```$Q```
M.@0````L$@``#@``!(H``#HP```!A!(```X```1]``!`Z```#M@2```.```$
MT0`!H```````$0``%0```X0``%K0````!!$``!$```3>``&@```````0```5
M```$$@``-A@```$0$@``#@```!(``:`P`````!$``!8```/4``!6$````*02
M```.```$E@`!H"`````$$0``%0``!.4``;(0`````!```!D```1P```[M```
M`M`2```.```$Z@`!H=P`````$```&0```_0``#4\````5!(```X```+6```4
ML````OP2```.```$]@``%[``````$@``#@``!%4``#=````"Q!(```X```0H
M```_B````6`2```.```#HP``````````(0``````!&(``#Z$````L!(```X`
M``3^```4L``````0```.```%!0`!H=P`````$```&0```_8``!1P`````!(`
M``T```/\``!/P```!602```.```#+0``6H``````$@```````E0``%IP````
M`!(```````*K``!:8``````2```````""P``6E``````$@```````WD``%I`
M`````!(```````(1``!:,``````2```````"^```6B``````$@```````Z0`
M`````````!$```````*C``!:$``````2````````PP``````````(```````
M`FH``%H``````!(```````-)``!9\``````2````````N@``6>``````$@``
M`````-T``%G0`````!(```````"I```````````2````````[```6<``````
M$@```````T(``%FP`````!(```````)X``!9H``````2````````^@``69``
M````$@```````)X``%F``````!(```````)<``!9<``````2```````!"P``
M66``````$@```````)```%E0`````!(```````,[``!90``````2```````"
M.0``63``````$@```````'T``````````!(```````,:``!9(``````2````
M```"C0``61``````$@```````1<``%D``````!(```````$B``!8\``````2
M```````!-P``6.``````$@```````B4``%C0`````!(```````+)``!8P```
M```2```````#6@``6+``````$@```````&X``%B@`````!(```````+"``!8
MD``````2```````!0P``````````$0```````O,``%B``````!(```````%2
M```````````B```````#(```6'``````$@```````6$``%A@`````!(`````
M``%]``!84``````2```````#DP``6$``````$@```````7$``%@P`````!(`
M``````)_``!8(``````2```````",0``6!``````$@```````P@``%@`````
M`!(```````!C``!7\``````2```````!A```5^``````$@```````98``%?0
M`````!(```````+;``!7P``````2```````!I```````````$0```````%4`
M`%>P`````!(```````*4``!7H``````2```````!L0``````````$0``````
M`W(``%>0`````!(```````-A``!7@``````2````````2P``5W``````$@``
M`````#P``%=@`````!(```````,"``!74``````2````````+```````````
M$@```````;P``%=``````!(```````.T```````````1```````#4P``5S``
M````$@```````K0``%<@`````!(```````!0``!7$``````2```````"FP``
M5P``````$@```````YL``````````!$```````1,``!6\``````2```````!
MR@``````````(````````BP``%;@`````!(```````+D```````````B````
M```"A@``5M``````$@```````KL``%;``````!(`````7T193D%-24-?3$E.
M2TE.1P!?7U),1%]-05``;&EB<&5R;"YS;RXU+C(X`&)O;W1?1'EN84QO861E
M<@!P97)L7V-O;G-T<G5C=`!P97)L7V9R964`<&5R;%]D97-T<G5C=`!P97)L
M7V%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L
M7W-Y<U]T97)M`'!E<FQ?<&%R<V4`4&5R;%]A=&9O<FM?;&]C:P!P97)L7W)U
M;@!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?879?9F5T8V@`4&5R;%]N97=84U]F;&%G<P!097)L7VUG7W-E=`!097)L
M7VYE=UA3`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?9V5T7W-V`%!,7VUE
M;6]R>5]W<F%P`%]?9VUO;E]S=&%R=%]?`%!E<FQ?9W9?9F5T8VAP=@!097)L
M7W-A9F5S>7-M86QL;V,`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P
M=@!03%]D;U]U;F1U;7``4$Q?=&AR7VME>0!097)L7V%V7W-H:69T`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L
M:6)P=&AR96%D+G-O+C``8VQO<V4`<'1H<F5A9%]G971S<&5C:69I8P!O<&5N
M-C0`<F5A9`!L<V5E:S8T`%]?97)R;F]?;&]C871I;VX`;&EB8RYS;RXV`&]P
M96YD:7(`7U]S=')N8W!Y7V-H:P!?7V9P<FEN=&9?8VAK`&%C8V5S<P!G971P
M:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E
M9&ER`'-T<F1U<`!S=')S='(`<W1R8VAR`%]?;&EB8U]S=&%R=%]M86EN`')E
M861L:6YK`%]?8WAA7V9I;F%L:7IE`&5X:70`7U]X<W1A=#8T`')M9&ER`%]?
M<F5G:7-T97)?871F;W)K`&UK9&ER`%]?;65M8W!Y7V-H:P!?7W-P<FEN=&9?
M8VAK`&UE;6-H<@!S=')T;VL`<F5A9&1I<C8T`&UE;6-P>0!S=')L96X`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`7U]L>'-T870V-`!?24]?<W1D:6Y?=7-E
M9`!R96%L;&]C`'-T9&5R<@!?7V5N=FER;VX`;&0N<V\N,0!?7W-T86-K7V-H
M:U]G=6%R9`!L:6)C<GEP="YS;RXQ`%]?;&EB8U]C<W5?:6YI=`!?7VQI8F-?
M8W-U7V9I;FD`>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`'!A<E]S971U<%]L:6)P871H`&=E=%]U<V5R;F%M
M95]F<F]M7V=E='!W=6ED`'!A<E]F:6YD<')O9P!P87)?96YV7V-L96%N`'!A
M<E]I;FET7V5N=@!P87)?;6MT;7!D:7(`<&%R7V1I<FYA;64`;7E?<&%R7W!L
M`'!A<E]C;&5A;G5P`'!A<E]C=7)R96YT7V5X96,`7V5D871A`'!A<E]B87-E
M;F%M90!?7V1A=&%?<W1A<G0`7V9D871A`%]E;F0`7U]B<W-?<W1A<G0`7U]S
M=&%R=`!?9G1E>'0`7V9B<W,`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R
M+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(``````````0`!``$``0`"``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``@`!
M``$``0`!``$`"0`"``(`!``#``0``P`"``(````)``,````````````"``(`
M``````D```````(`!`````(``@`````````(``(``@````(````"````"0``
M``(``@````(`"``'``````````(```````(````"``8```````(```````4`
M`@`"``(``@`"``(````$``,``@`"``$``0```ZP````0````(`UI:10````%
M```%"P```````0`"```!^P```!`````P#6EI$@````@```45````$`UI:1``
M```$```%'P```````0`%```"2@```!``````"6D9=`````D```4I````$`EI
M&7(````'```%-0```!`-:6D4````!@``!0L````0#6EI$@````,```45````
M$`UI:1`````"```%'P`````````````````!G_@````#``&?_`````,``:`@
M`````P`!H=@````#/!P``B><"\`#F>`A)[W_X*^\`!"OOP`<CX*!&!!```0`
M````CYF!&`,@^`D`````C[\`'`/@``@GO0`@`````#P<``(GG`N``YG@(2>]
M_["/F8$(K[``-*^\`!BOOP!,K[4`2*^T`$2OLP!`K[(`/*^Q`#B/D(%XKZ4`
M)">E`"2OI@`@)Z8`(*^D`%`GI`!0C@(``*^B`"P#(/@)`````(^\`!B/AH#D
MCYF`6(^$@+@$$1`S`,`H)8^\`!B/@H%,D$(``!!``&B/F8$\CY&!6(^9@)0#
M(/@)CB0``(^\`!B00P-FCB0``(^9@)0T8P`"`R#X":!#`V8\`T``CZ0`4)!%
M`V:/O``8)(0`!32E``$`@Q@K$&``?J!%`V:/F8$L`R#X"0`$(("/I0`DC[P`
M&(^F`%",HP``CX2`7(^(@"BL0P``CX.`)(R'```HQ``"K0*Q]"1C7@RL1P`(
M)`<`!*Q#``2/@X`D)&->$*Q#``R/@X`H%(``"JQGL?@`!D"`)*,`!"1$`!``
MJ$`AC&4``"2$``0D8P`$%0/__*R%__R/D8`H``88@(^%@"0DQ@`#`$,8(8^9
M@,ROH``0`$`X)8XDL@`DI360`R#X":Q@``R/O``8$$``-0!`F"6/F8%0)[0`
M*`,@^`F.)+(``H`H)8^\`!B/DH`DCX2`)"92*\P"0,@E!!$%522$6YP00``M
MC[P`&(^9@60#(/@)CB2R`(^\`!B/F8#8`R#X"0`````"8!`ECZ0`+(X#```4
M@P`\C[P`&(^_`$R/M0!(C[0`1(^S`$"/L@`\C[$`.(^P`#0#X``()[T`4`,@
M^`D`````C[P`&(^#@"@00``JK&*R`(^9@6B/D8%8`R#X"0!`("6/O``8CYF`
ME`,@^`F.)```C[P`&!``_XJ@0`<1CYF`L`,@^`F.)+(`C[P`&!``_\<`0)@E
MCY6`*(ZDL?P0@``%CYF`8`01#W<`````$`#_S8^\`!B/A(`D`H`H)0)`R"4$
M$04:)(1;.(^\`!@`0"`E$$#_Q*ZBL?P0`/_RCYF`8(^$@"2/A8$0CYF`]`,@
M^`DDA%U$CYF!%`,@^`DD!``!CYF!8`,@^`D```````````/@`"4$$0`!````
M`#P<``(GG`AT`Y_@(0``^"6/A(`8CZ4``">F``0D`?_X`Z'H)">]_^"/AX`<
MCXB`(*^H`!"OH@`4K[T`&(^9@0`#(/@)`````!``__\``````````#P<``(G
MG`@@`YG@(8^$@"B/@H!D)(2@-!!$``6/F8&4$R```P`````#(``(``````/@
M``@`````/!P``B><!^@#F>`ACX2`*(^%@&0DA*`T`*0H(P`%*(,`!1?"`$4H
M(0`%*$,0H``%CYF`I!,@``,``````R``"``````#X``(`````#P<``(GG`><
M`YG@(2>]_^"OL``8CY"`**^\`!"OOP`<D@*AX!1```V/@H&<$$``!8^"@&B/
MF8&<`R#X"8Q$``"/O``0CYF`)"<Y&!`$$?_+`````"0"``&B`J'@C[\`'(^P
M`!@#X``()[T`(#P<``(GG`<P`YG@(8^9@"0G.1A($`#_S```````````/!P`
M`B><!Q`#F>`A)[W]4(^+@7@DA0`X)Z(`&*^\`!`DB`!XK[\"K`!`&"6OL0*H
MK[`"I(UF``"OI@*<C*<``"2E``@D8P`0K&#_\*Q@__BL9__TC*;__!4%__BL
M9O_\)$H"`(Q)`&@D0@`(K$``>(Q%`#B,0P`\C$@`9(Q'``@!)4@FC$8`#`$#
M0":,1?_XC$/__`#I."8`R#`F`*<H)@!F&"8``S?"``4H0``#&$``IB@E`&48
M)15"_^JL0P!\C(@`!#P"6H*,A@``C(<`#"1">9F,A0`(``ANP@`&&4"/N``<
M``=P@HR)`!0`!2^`C(P`)`!M&"6,B@`<``=O@*R`````KB@EK(``"`&E<"6/
MI0`D`P+`(:R``!``"'E`K(``&`"B*"&L@``@`2YH)@,,P"$!XW@E`:AH)`$J
M&"8`JB@A`?AX(0&I:"8`9Q@D``C`@@"M*"&/K0`L`&H8)@`&-X`!XQ@A``A_
M@`#8,"4!YL`E``.&P@`#R4`!HF@A`=AX)@,P,"4!J6@A`>-X)`"F*"$![G@F
M``.(@@`#-X`!KQ@ACZT`-``%AL(`!<E``-$P)0,P>"4!HF@A`&\8(0,&>"8!
MKF@A`>5X)`'X>"8`!8B"``5W@`&O*"&/KP`\``.&P@`#R4`!T7`E`S!H)0'B
M>"$`K2@A`,YH)@'X>"$!H\`D`P;`)@`#B((``V^``?@8(8^O`$0`!8;"``7)
M0`&Q:"4#,,`E`>)X(0!X&"$!S<`F`>8P(0`%B((`!7^``P7`)`,.P"8`V"@A
M`?$P)8^O`$P``X;"``/)0`'B>"$#,,`E`+@H(0&FP"8![G`A``.(@@`#?X`#
M`\`D`PW`)@'8&"$!\7`ECZ\`5``%AL(`!<E``>)X(0,PP"4`>!@A`,[`)@'M
M:"$`!8B"``5_@`,%P"0#!L`F`;@H(0'Q:"6/KP!<``.&P@`#R4`!XG@A`S#`
M)0"X*"$!S<`F`>8P(0`#B((``W^``P/`)`,.P"8`V!@A`?$P)8^O`&0`!8;"
M``7)0`'B>"$#,,`E`'@8(0&FP"8![G`A``6(@@`%?X`#!<`D`PW`)@'8*"$!
M\7`ECZ\`;``#AL(``\E``>)X(0,PP"4`N"@A`,[`)@'M:"$``XB"``-_@`,#
MP"0#!L`F`;@8(0'Q:"6/KP!T``6&P@`%R4`!XG@A`S#`)0!X&"$!S<`F`>8P
M(0`%B((`!7^``P7`)`,.P"8`V"@A`?$P)8^O`'P``X;"``/)0`'B>"$#,,`E
M`+@H(0&FP"8![G`A``.(@@`#?X`#`\`D`PW`)@'8&"$!\7`ECZ\`A``%AL(`
M!<E``>)X(0,PP"4`>!@A`,[`)@'M:"$`!8B"``5_@`,%P"0#!L`F`;@H(0'Q
M:"6/KP",``.&P@`#R4`!XG@A`S#`)0"X*"$!S<`F`>8P(0`#B((``W^``P/`
M)`,.P"8`V!@A`?$P)8^O`)0`!8;"``7)0`'B>"$#,,`E`'@8(0&FP"8![G`A
M``6(@@`%?X`#!<`D`PW`)@'8*"$!\7`ECZ\`G``#AL(``\E``>)X(0,PP"4`
MN"@A`,[`)@'M:"$#`W@D`>9X)@&O:"&/KP"D``6&P@`%R4```\>```,8@@'B
M>"$#`\`E`S`8)0&C&"$!V&@F`>9X(0&E,"0`!6B"``4O@`#.,"8`K6@ECZ4`
MK``#AL(``\E``>9X(0"B*"$#,#`E`>9X(0,-,"8``X""`*YP(0##*"0``Q^`
M`+@H)@'%<"$`<"@ECZ,`M``/SL(`#S%``&(8(0#9,"4!QG`A`:4P)@!X&"$`
MSS`D`,TP)@!F&"&/I@"\/`)NV0`/R((T0NNA``]_@`#","$!^7@E`,TP(0"O
M:"8!KF@F`,TP(8^M`,0`#H;"``[!0``.R((`#G>``Q#`)0&B:"$`>!@A`=EP
M)0&E*"$![F@F`:-H)@`#AL(``\B"``/!0`"M*"$``V^`CZ,`S`,0P"4`V#`A
M`&(8(0&Y:"4`;Q@A`<UX)@'F>"8`!H;"``;(@@`&P4``;Q@A``9_@(^F`-0#
M$,`E`+@H(0#","$!^7@E`,XP(0&O<"8!Q7`F``6&P@`%R((`!<%``,XP(0`%
M=X"/I0#<`Q#`)0!X&"$`HB@A`=EP)0"M*"$![F@F`:-H)@`#AL(``\B"``/!
M0`"M*"$``V^`CZ,`Y`,0P"4`V#`A`&(8(0&Y:"4`;Q@A`<UX)@'F>"8`!H;"
M``;(@@`&P4``;Q@A``9_@(^F`.P#$,`E`+@H(0#","$!^7@E`,XP(0&O<"8!
MQ7`F``6&P@`%R((`!<%``,XP(0`%=X"/I0#T`Q#`)0!X&"$`HB@A`=EP)0"M
M*"$![F@F`:-H)@`#AL(``\B"``/!0`"M*"$``V^`CZ,`_`,0P"4`V#`A`&(8
M(0&Y:"4`;Q@A`<UX)@'F>"8`!H;"``;(@@`&P4``;Q@A``9_@(^F`00#$,`E
M`+@H(0#","$!^7@E`,XP(0&O<"8!Q7`F``6&P@`%R((`!<%``,XP(0`%=X"/
MI0$,`Q#`)0!X&"$`HB@A`=EP)0"M*"$![F@F`:-H)@`#AL(``\B"``/!0`"M
M*"$``V^`CZ,!%`,0P"4`V#`A`&(8(0&Y:"4`;Q@A`<UX)@'F>"8`!H;"``;(
M@@`&P4``;Q@A``9_@(^F`1P#$,`E`+@H(0#","$!^7@E`,XP(0&O<"8!Q7`F
M``6&P@`%R((`!<%``,XP(0`%=X"/I0$D`Q#`)0!X&"$`HB@A`=EP)0"M*"$!
M[F@F`:-H)@`#AL(``\B"``/!0`"M*"$``V^`CZ,!+`,0P"4`V#`A`&(8(0&Y
M:"4`;Q@A`<UX)@'F>"8`!H;"``;(@@`&P4``;Q@A``9_@(^F`30#$,`E`+@H
M(0#","$!^7@E`,XP(0&O<"8!Q7`F``6&P@`%R((`!<%``,XP(0`%=X"/I0$\
M`Q#`)0!X&"$`HB@A`=EP)0"M*"$![F@F`:-H)@`#AL(``\B"``/!0`"M*"$`
M`V^`CZ,!1`,0P"4`V#`A`&(8(0&Y:"4`;Q@A`<UX)@'F>"8`!H;"``;!0`!O
M&"&/KP%,`Q#`)0`&R((`!C>``+@H(0'B>"$`V3`E``6&P@`%P4`![G@A`:9P
M)@'%<"8#$,`E`>YX(8^N`50`>!@A``7(@@`%+X```X;"``/!0`'"<"$`N2@E
M`Q#`)0'-<"$`Q6@F`?AX(0&C:"8!S7`ACZT!7#P"CQL`#\["``.`@@`/P4``
M`Q^`-$*\W`!P&"4#&<`E`:)H(0'8<"$`H\`E`:9H(0,/P"0`HS`D`P;`)0&X
M:"&/N`%D``Z&P@`.R4``#XB"``\W@`,"P"$`T3`E`S!X)0&O:"$`9G@E`&;(
M)`,%P"$![G@D`?EX)0`.B((`#B^``?AP(8^X`6P`#8;"``W)0`"Q*"4#,'@E
M`P+`(0'/<"$`Q7@E`,7()`,#P"$![7@D`?EX)0`-B((`#1^``?AH(8^X`70`
M#H;"``[)0`!Q&"4#,'@E`P+`(0&O:"$`HW@E`*/()`,&P"$![G@D`?EX)0`.
MB((`#C>``?AP(8^X`7P`#8;"``W)0`#1,"4#,'@E`P+`(0'/<"$`9G@E`&;(
M)`,%P"$![7@D`?EX)0`-B((`#2^``?AH(8^X`80`#H;"``[)0`"Q*"4#,'@E
M`P+`(0&O:"$`Q7@E`,7()`,#P"$![G@D`?EX)0`.B((`#A^``?AP(8^X`8P`
M#8;"``W)0`!Q&"4#,'@E`P+`(0'/<"$`HW@E`*/()`,&P"$![7@D`?EX)0`-
MB((`#3>``?AH(8^X`90`#H;"``[)0`#1,"4#,'@E`P+`(0&O:"$`9G@E`&;(
M)`,%P"$![G@D`?EX)0`.B((`#B^``?AP(8^X`9P`#8;"``W)0`"Q*"4#,'@E
M`P+`(0'/<"$`Q7@E`,7()`,#P"$![7@D`?EX)0`-B((`#1^``?AH(8^X`:0`
M#H;"``[)0`!Q&"4#,'@E`P+`(0&O:"$`HW@E`*/()`,&P"$![G@D`?EX)0`.
MB((`#C>``?AP(8^X`:P`#8;"``W)0`#1,"4#,'@E`P+`(0'/<"$`9G@E`&;(
M)`,%P"$![7@D`?EX)0`-B((`#2^``?AH(8^X`;0`#H;"``[)0`"Q*"4#,'@E
M`P+`(0&O:"$`Q7@E`,7()`,#P"$![G@D`?EX)0`.B((`#A^``?AP(8^X`;P`
M#8;"``W)0`!Q&"4#,'@E`P+`(0'/<"$`HW@E`*/()`,&P"$![7@D`?EX)0`-
MB((`#3>``?AH(8^X`<0`#H;"``[)0`#1,"4#,'@E`P+`(0&O:"$`9G@E`&;(
M)`,%P"$![G@D`?EX)0`.B((`#B^``?AP(8^X`<P`#8;"``W)0`"Q*"4#,'@E
M`P+`(0'/<"$`Q7@E`,7()`,#P"$![7@D`?EX)0`-B((`#1^``?AH(8^X`=0`
M#H;"``[)0`!Q&"4#,'@E`P+`(0&O:"$`HW@E`*/()`,&P"$![G@D`?EX)0`.
MB((`#C>``?AP(8^X`=P`#8;"``W)0`#1,"4#,'@E`P+`(0'/<"$`9G@E`&;(
M)`,%P"$![7@D`?EX)0`-B((`#2^``?AH(8^X`>0`#H;"``[)0`"Q*"4#,'@E
M`P+`(0&O:"$`Q7@E`,7()`,#P"$![G@D`?EX)0`.B((`#A^``?AP(8^O`>P`
M#8;"``W)0`!Q&"4#,,`E`>)X(0'8<"$`H\`E`*/()`'F,"$##<`D`QG`)0,&
MP"&/I@'T``V`@@`-;X``#L["``YY0`&P:"4`PA`A`?EX)0!M,"4##\`A`$4H
M(0!M>"0`SC`D`,\P)0#%,"&/I0'\/`+*8@`.R((T0L'6``YW@`"B*"$!V7`E
M`!B&P@`8>4``HR@A`:X8)@'P>"4`>!@F`,\P(0"C*"&/HP($``:&P@`8R((`
M!GE``!C'@`!B&"$#&<`E`?!X)0"O*"$`;1@A`=AX)@'F>"8`!LB"`&\8(0`&
M?X"/I@(,``6&P@'Y>"4`PC`A``5I0`#.,"$##W`F`;!H)0'%<"8`;1@A``7(
M@@#.,"$`!7>`CZ4"%``#AL(``VE``*(H(0'9<"4!L&@E`,TP(0"X*"$![F@F
M`:-H)@`#R((`K2@A``-O@(^C`AP`!H;"`;EH)0!B&"$`!LB"`&\8(0'->"8!
MYG@F``;!0`!O&"$`!G^`CZ8")`,0P"4`N"@A`,(P(0'Y>"4`SC`A`:]P)@'%
M<"8`!8;"``7(@@`%P4``SC`A``5W@(^E`BP#$,`E`'@8(0"B*"$!V7`E`*TH
M(0'N:"8!HV@F``.&P@`#R((``\%``*TH(0`#;X"/HP(T`Q#`)0#8,"$`8A@A
M`;EH)0!O&"$!S7@F`>9X)@`&AL(`!LB"``;!0`!O&"$`!G^`CZ8"/`,0P"4`
MN"@A`,(P(0'Y>"4`SC`A`:]P)@'%<"8`!8;"``7(@@`%P4``SC`A``5W@(^E
M`D0#$,`E`'@8(0"B*"$!V7`E`*TH(0'N:"8!HV@F``.&P@`#R((``\%``*TH
M(0`#;X"/HP),`Q#`)0#8,"$`8A@A`;EH)0!O&"$!S7@F`>9X)@`&AL(`!LB"
M``;!0`!O&"$`!G^`CZ8"5`,0P"4`N"@A`,(P(0'Y>"4`SC`A`:]P)@'%<"8`
M!8;"``7(@@`%P4``SC`A``5W@(^E`EP#$,`E`'@8(0"B*"$!V7`E`*TH(0'N
M:"8``X;"`:-H)@`#P4```\B"`*TH(0`#;X"/HP)D`Q#`)0#8,"$`8A@A`;EH
M)0`&AL(`!L%``&\8(0'->"8#$,`E`>9X)@"X*"$`!LB"`&\8(0`&?X"/I@)L
M``6&P@`%P4``PC`A`?EX)0,0P"4`>!@A`,XP(0&OP"8#!<`F``7(@@#8,"$`
M!<>`CZ4"=``#AL(``W%``*(H(0,9P"4!T'`E`*TH(0'X:"8`SC`A`:-H)@`#
MR((`K2@A``-O@(^C`GP`!H;"``9Q0`!B&"$!T'`E`*XH(0&Y<"4##F@F`&\8
M(0&F:"8`!LB"`&T8(0`&;X"/I@*$``6&P@`%>4``PC`A`?!X)0!O&"$!N7@E
M`<]H)@#8,"$!I6@F``.&P@#-,"&/K0*,``/!0``%R((#$,`E``4O@`#8P"$!
MHF@A`+DH)0&N:"$`&#%``>5P)@`8AL(!PW`F``/(@@&N:"$``W>``-`8)8^F
M`I0!HV@A`,(P(0'9$"4`HA@F`,\P(0!X&"8`#<["``UQ0`##,"$`&'B"`!@?
M@`'9<"4`SC`A`&\8)0!I2"$`2A`A`,A`(:R)`!0`[3@AK((`'`"L*"&LB``$
MK(<`#*R%`"2/HP*<C6(``!1B``6/OP*LC[$"J(^P`J0#X``()[T"L(^9@6`#
M(/@)`````#P<``(GG/1D`YG@(2>]_\BOO``0K[\`-*^V`#"OM0`LK[0`**^S
M`"2OL@`@K[$`'!"``$2OL``8CX*`G(Q5```2H`!``````(""```00``$``"0
M)20#`#T40P`A`````(ZP```2```3)!8`/0"@H"4`@)@E`J"()8^9@*`"`"`E
M`D`P)0,@^`D"8"@E`A(8(11```2/O``0@&(``!!6`!D`````)C$`!(XP```6
M`/_SCYF`H(^_`#0"`!`EC[8`,(^U`"R/M``HC[,`)(^R`""/L0`<C[``&`/@
M``@GO0`X`("0)292``&"0@``$$```P`````40__[`````!``_]@"1)`C`C6(
M(R92``$`$8B#`A*`(:Z1``"/OP`T`@`0)8^V`#"/M0`LC[0`*(^S`"2/L@`@
MC[$`'(^P`!@#X``()[T`.(^_`#0``(`EC[8`,`(`$"6/M0`LC[0`*(^S`"2/
ML@`@C[$`'(^P`!@#X``()[T`.#P<``(GG/+P`YG@(2>]_\BOLP`LK[0`,">T
M`!BOL@`HK[$`)`"`B"6OL``@K[P`$*^_`#2/DX%XCY"`)(^2@)R.8@``)A`K
MS*^B`!P"@"@E`@#()001_XT"("`E$$``$H^\`!"/HP`8CD(````#&(``0Q`A
MC$,`!!!@__2L0P``)$(`!(Q#``048/_]K$,```*`*"4"`,@E!!'_?`(@("44
M0/_PC[P`$(^C`!R.8@``%&(`"(^_`#2/M``PC[,`+(^R`"B/L0`DC[``(`/@
M``@GO0`XCYF!8`,@^`D`````/!P``B><\A`#F>`A)[W_N"0"`#VOL0`HK[,`
M,`"`F"6OL``D`*"`):^\`!"OOP!$K[<`0*^V`#ROM0`XK[0`-*^R`"R/D8%X
M@*,``(XD``"OI``<%&(``H^9@00DL``!`R#X"0(`("4GI0`8C[P`$`)@("6/
MF8`D)SDKS`01_TL`0*`EC[P`$!!``%D`0)`ECYF!!`,@^`D`0"`E`%00*Q!`
M`$>/O``0C[(`&(^5@)P`$K"`@F(``!!``'XD`P`]$$,`?``````0```#`F`@
M)1!#``4`````)(0``8""```40/_[``````"3("..L@``)I0``H^9@20"A"`A
M`R#X"0)6D"&/O``0$$``:*Y"``"/HP`8)F0``8ZB``""90````,8@`!#$"&,
M0P``$*``#:!E```D`@`]$*(`"@`````0```#)`4`/1!%``8`````)(0``8""
M__\D8P`!%$#_^J!B```D!``])&(``:!D```F$``!@@/__R1"``$48/_\H$/_
M_P``$"6/I``<CB,``!2#`$V/OP!$C[<`0(^V`#R/M0`XC[0`-(^S`#"/L@`L
MC[$`*(^P`"0#X``()[T`2"80``&"`O__)E(``1!`_^VB0O__)A```8("__\F
M4@`!%$#_]Z)"__\0`/_G```0)8^5@)R.MP``CN(``!!``"\"X!`E$````@``
M&"4"0!@E)$(`!(Q$```4@/_\)'(``21C``,``R"`CX*`*(Q#L?`48``6CYF!
M*(^9@20D`P`!`R#X":Q#L?`00``8C[P`$(^9@8@`$K"``N`H)0+`,"4#(/@)
M`$`@)8^\`!``0!@EKJ(``"9"``$``A"``&(8(:Q@```0`/^+K[(`&`"`*"4"
MX"`E`R#X"0`2L("/O``0`$`8)11`__.NH@``$`#_MB0"__\0`/^-```@)20$
M``@0`/_9``"0)8^9@6`#(/@)`````#P<``(GG.\\`YG@(2>]_PBOL@#8K[P`
M&*^_`/2OO@#PK[<`[*^V`.BOM0#DK[0`X*^S`-ROL0#4K[``T(^2@7B.0@``
MKZ(`S!"```0`````@((``!1``!``@(@ECZ,`S(Y"```48@!MC[\`](^^`/"/
MMP#LC[8`Z(^U`.2/M`#@C[,`W(^R`-B/L0#4C[``T`/@``@GO0#XCYF`A`,@
M^`D`````C[P`&!!`_^P`0)@ECY2`)">W`"B/E8`DCY:`)(^"@"0FE%K4)K5:
MW";6,/2OH@`DCYF`K`,@^`D"8"`E$$``08^\`!B/F8&@)%``$P*`*"4#(/@)
M`@`@)1!`__6/O``8CZ(`)`(`("6/F8&@`R#X"21%6M@00/_NC[P`&(^9@00#
M(/@)`B`@)0(`("6/O``8CYF!!`,@^`D`0/`EC[P`&`/"$"&/F8$D`R#X"21$
M``(D!O__C[P`&"0%``$`0"`EK[``%`*@."6OL0`0CYF`@`,@^`D`0/`E)`0`
M`X^\`!@"X#`ECYF`F`,@^`D#P"@E)`3__Q!$``:/O``8CZ(`0"0$0``P0O``
M$$0`%P+`R"6/F8%4`R#X"0/`("6/O``8CYF!A`,@^`D#P"`EC[P`&(^9@*P#
M(/@)`F`@)11`_\&/O``8CYF`B`,@^`D"8"`EC[P`&(^9@6P#(/@)`B`@)1``
M_Y6/O``8!!'_?`/`("40`/_KC[P`&(^9@6`#(/@)`````#P<``(GG.T4`YG@
M(2>]_S"/F8"0)Z8`&*^P`,2OO``0K[$`R`"`B"6OOP#,)`0``X^0@7@"("@E
MC@(``*^B`+P#(/@)`````!1```^/O``0CZ,`,"0$0``P8_``$&0``S0$H``4
M9``)`````(^9@,0D!0`"`R#X"0(@("6/O``0$````BQ"``$``!`ECZ0`O(X#
M```4@P`%C[\`S(^Q`,B/L`#$`^``"">]`-"/F8%@`R#X"0`````\'``")YSL
M7`.9X"$GO>_`CYF!2"0&#_^OLA`LK[P`$*^T$#0`H*`EK[,0,`"`F"6OL!`D
M)[``'*^_$#ROM1`X`@`H):^Q$"B/DH%XCX2`)(Y"```DA%KDKZ(0'`,@^`D`
M````&$``.H^\`!`D4?__CX2!6">C$"``<1@A@&/O_!1@`"",E0``$B``)H^9
M@-PD!0`O`B`P)0,@^`D"`"`E$$``((^\`!"/F8"4`R#X"0*@("4"(#@EC[P`
M$`(`,"4"8"@ECYF`M`,@^`D`0"`EC[P`$(^C$!R.0@``%&(`'X^_$#R/M1`X
MC[00-(^S$#"/LA`LC[$0*(^P$"0#X``()[T00(^9@-P`0(@E)`4`+P(@,"4#
M(/@)`@`@)11`_^*/O``0CYF`E`,@^`D"H"`E`H`P)8^\`!`"8"@ECYF!1`,@
M^`D`0"`E$`#_XH^\`!"/@H%8$`#_\XQ5``"/F8%@`R#X"0`````\'``")YSJ
M]`.9X"$GO?_@CX*!6(^9@)2OOP`<K[P`$`,@^`F,1```C[P`$`!`("6/OP`<
M)[T`((^'@"R/A8`DCX:!<(^9@/`DYYIT`R``""2E6O0\'``")YSJH`.9X"$G
MO?_8CYF`E*^P`""OOP`DK[P`&(^0@5@#(/@)C@0``(^\`!B/F8`P!!'_W0!`
M("6/O``8CYF`E`,@^`F.!```C[P`&`!`("6OH``4CX>`)(^%@"2/F8#().=>
M"(^&@#0DI5L0`R#X":^G`!"/OP`DC[``(`/@``@GO0`H/!P``B><ZA@#F>`A
M)[W?P(^9@3"OL2`TK[\@/*^\`!BOLB`X)[(0**^P(#`GL``DCY&!>(XB``"O
MHB`L`R#X"0`````D!A`!C[P`&"0%``&OH@`0`@`@)8^"@"2/AX`DCYF`@"1"
M6S0DYULH`R#X":^B`!0D!A``C[P`&`)`*"6/F8%(`R#X"0(`("4$0``;C[P`
M&(^9@20D1``!`R#X"0!`@"6/O``8$$``"@!`&"6/F8%\`@`P)0)`*"4#(/@)
M`$`@)0!0@"&/O``8`$`8):(```"/I"`L`&`0)8XC```4@P`(C[\@/(^R(#B/
ML2`TC[`@,`/@``@GO2!`$`#_]0``&"6/F8%@`R#X"0`````\'``")YSI"`.9
MX"&/F8`X$`#_MP`````\'``")YSH\`.9X"$GO>[XCX*!>(^9@"2OO``@K[\1
M!"<Y*\ROLQ#L`*"8):^Q$.0`@(@EK[`0X">E`#2OOA$`K[<0_*^V$/BOM1#T
MK[00\*^R$.BOH@`LCX2`)(Q"```DA%LXKZ(0W`01_0@`````)`4`+X^\`"`"
M("`ECYF!#`,@^`D`0(`E$$``&8^\`""/A(`D`B`H)8^9@"0G.2X@!!']CR2$
M6T0"(!`EC[P`((^C`"R/I!#<C&,``!2#`'Z/OQ$$C[X1`(^W$/R/MA#XC[40
M](^T$/"/LQ#LC[(0Z(^Q$.2/L!#@`^``"">]$0B/F8$$CY*`)`,@^`D"("`E
M`F`@)8^\`"`F15M4CYF`P`,@^`D`0*`EC[P`(!!`_]P`0+@ECY:`)(^3@"2"
MX@``CY6`)";66M000`!!)G-;8!(```:/F8&@`N`H)0,@^`D"`"`E$$``,(^\
M`""/F8$$`R#X"0+@("4D`P`O`N(@(8^\`""`A/__%(,`#`!`*"4D0O_^)`0`
M`0+B&"$`ER`C)`8`+P"#*"&@8``!)&/__X!B``$01O_[`````":"``$`12@A
M**40`!"@_[6/F8"`)[X`W":G6UBOL0`8)`80`*^S`!0D!0`!K[<`$`,@^`D#
MP"`E)Z8`.(^\`"`D!``#CYF`F`,@^`D#P"@E%$``!H^\`""/H@!0-`.``#!"
M\``00P`5CYF`Q(^9@,`F15M4`R#X"0``("6/O``@$$#_F`!`N"6"X@``%$#_
MP0`````2```:CYF!H`+`*"4#(/@)`@`@)1!`__"/O``@`L"X)1``_](D!0`!
M)`4``0,@^`D#P"`E%$#_Z(^\`""/A(`D`\`H)8^9@"0G.2X@!!']%"2$6T2/
MO``@CYF!@`,@^`D#P"`E$`#_@H^\`"`D!0`!$`#_O@+`N"6/F8%@`R#X"0``
M``"`@P``$&``!P"`$"4DA``!.&,`+P"#$`J`@P``%&#__"2$``$#X``(````
M`#P<``(GG.8``YG@(2>]_]BOO``0K[\`)*^Q`"`0@``CK[``'(""```00``@
M`("`)8^9@00#(/@)`````"1"__\"`A`A`@(8*Q!@`"F/O``0@$0``"0#`"\4
M@P`<`````!````0D!``O@$,``!1D`!<`````)$+__Q8"__L`````@$,``"0"
M`"\08@`[CYF!@(^$@"2/OP`DC[$`((^P`!PDA%M@`R``"">]`"B/A(`DCYF!
M@"2$6M2/OP`DC[$`((^P`!P#(``()[T`*!````0D!``O@$,``!!D``<`````
M)$+__P("&"L48/_Z`````!("_^,`````$```!"0$`"^`0P``%&0`!0`````D
M0O__`@(8*Q1@__H``````%`0(R1#``(L8Q`!$&``#8^1@"@D!Q``CYF`T"1&
M``$"`"@E`R#X"28DH?`F(J'PC[\`)(^Q`""/L``<`^``"">]`"B/OP`D```0
M)8^Q`""/L``<`^``"">]`"B/A(`D$`#_SB2$6M0\'``")YSD?`.9X"$GO?^8
MCX*`+">C`""OLP!4)$*:4*^\`!"OOP!D)$4`(*^V`&"OM0!<K[0`6*^R`%"O
ML0!,K[``2(^3@7B.9```KZ0`1(Q(```D0@`0)&,`$*QH__",1__TC$;_^(Q$
M__RL9__TK&;_^!1%__:L9/_\CY"`)">R`!R/A(`DE$(``"80+4"/E(`D)(1;
M9(^5@"0"`,@E!!'\.J1B```"`,@EC[P`$(^$@"2/EH`DCY&`)`01_#,DA%MP
M`@#()8^\`!"/A(`D!!'\+B2$6W@"`,@EC[P`$(^$@"0$$?PI)(1;A`(`R"4$
M$?PF)H1;C`(`R"6/O``0CX2`)`01_"$DA%N<`@#()001_!XFI%LX`@#()001
M_!LFQ%NH`@#()001_!@F)%NT`@#()8^\`!"/A(`D!!'\$R2$6\`"`,@EC[P`
M$(^$@"0$$?P.)(1;1`)`*"6/O``0CY"`)(^$@"0F$"O,`@#()001^ZDDA%O,
M$$``-(^\`!`F)%NTCY&`)"8Q+B`"(,@E!!'\-@!`*"6/O``0CX2`)`)`*"4"
M`,@E!!'[FR2$6^`00``'C[P`$(^$@"0`0"@E`B#()001_"DDA%OTC[P`$(^$
M@"0"0"@E`@#()001^XXDA%P`$$``'(^\`!`FI%LX`B#()001_!T`0"@EC[P`
M$(^%@"0FA%N,`B#()001_!<DI5PPCZ,`1(YB```48@`IC[P`$(^_`&2/M@!@
MC[4`7(^T`%B/LP!4C[(`4(^Q`$R/L`!(`^``"">]`&B/D8`D$`#_TB8Q+B"/
MA(`D`D`H)0(`R"4$$?ML)(1<$!!```>/O``0)L1;J`(@R"4$$?O[`$`H)1``
M_]Z/O``0CX6`)"0&``J/F8"@)Z0`,0,@^`DDI5PD%$#_UH^\`!`GI0`[`B#(
M)001^^TFQ%NH$`#_T(^\`!"/F8%@`R#X"0`````\'``")YSAK`.9X"$GO?_0
M)`/__Z^Q`"BOL``DK[P`$*^_`"R/D(%XCY&`*(X$``".(J`0KZ0`'!!#``F/
MA(`DCZ0`'(X#```4@P`6C[\`+(^Q`"B/L``D`^``"">]`#`GI0`8CYF`)"<Y
M*\P$$?LV)(1;J!!```B/O``0@$(``!!```4`````.$(`,``"$"L0`/_KKB*@
M$```$"40`/_HKB*@$(^9@6`#(/@)`````#P<``(GG.#\`YG@(2>]_^"/F8%<
MK[P`$*^_`!P#(/@)`````(^\`!"/F8&0`R#X"0!`("400``$C[\`'(Q"```#
MX``()[T`(```$"4#X``()[T`(#P<``(GG."H`YG@(2>]_[B/F8`D)Z4`**^Q
M`#0G.2O,K[P`(*^S`#P`@)@EK[(`.*^_`$2OM`!`K[``,(^1@7B/DH`DCB(`
M`"9$7#2OH@`L!!'Z_``````00``%C[P`(`!`@"6`0@``%$``$H^9@:2/F8`D
M)D1<-"<Y+B`$$?N&`F`H)8^\`""/HP`LCB(``!1B`#"/OP!$C[0`0(^S`#R/
ML@`XC[$`-(^P`#`#X``()[T`2`)@*"4#(/@)`@`@)11`__&/O``@CYF!!`,@
M^`D"8"`E`@`@)8^\`""/F8$$`R#X"0!`H"6/O``@`H(0(8^9@20#(/@))$0`
M`B0&__^/O``@`$`@)0!`H"6OL``8)`4``:^S`!"/@H`DCX>`)(^9@(`D0EM4
M).=;6`,@^`FOH@`4)D1<-(^\`""/F8`D)SDN(`01^U0"@"@E$`#_SH^\`""/
MF8%@`R#X"0`````\'``")YS?2`.9X"$GO8`0CX.!>#P"__^OM7_<`("H):^T
M?]@T!(%0K[%_S"1%?N2OL'_(K[]_[*^^?^BOMW_DK[9_X*^S?]2OLG_0)[W^
M6(^1@"0GI@`@CY2`)*^\`"@GIP`@`(8@(:^C`#B,9@``-`.!4`""$"&/A(`D
M`&<8(28Q7$0`92@ACX.`)"206_2/A(`D)I0KS*Q`?O`D8UQ4K%!_`*^D`#PD
MA%LXK$-^Z`*`R"6/@X`DK$!_%*Q1?O0D8UK4K$!^_*Q#?NPT`X%,`&<8(:QF
M``"/@X`D)&-;^*Q#?P2/@X`D)&-<7*Q#?PB/@X`D)&-;/*Q#?PR/@X`D)&-<
M9*Q#?Q"/@X`D)&-<:`01^G2L0W[X$$``!(^\`"B`0P``%&`!I8^9@#R/F8!`
M!!'_1@````"/O``H$$`!80!`D"6/F8$$`R#X"0)`("6/O``H``(00(^9@20#
M(/@))$0``8)#````0(@E$&``$8^\`"B/EH`D`B"8)2;67'220@``)E(``8^9
M@(`D!O__)`4``0)@("6OH@`0`R#X"0+`."4F<P`"@D(``!1`__2/O``H/!;_
M_X^3@"0GHP`@-`*!4`(`("4`0Q`A)M!_`";6?N0`4(`A-`*!4"9S,QP`0Q`A
M$```!0!6L"$F$``$C@0``!"``!0``````H#()001^C@"P"@EC[P`*!!`__<`
M0)`E@$(``!!`__0"8,@E!!'\!`)`("400/_PC[P`*(^9@8`#(/@)`D`@)8^\
M`"@40``A`$"`)3P6__^/DH`D-`*!4">C`"`FTW[H`$,0(0``N"4F4C,<`%.8
M(30"@5`GI``@`!<8@`!$$"$`5A`A`$,0(8Q0?N@2```.`````(("```00``+
M`D#()001^^4"`"`E)O<``11``&./O``H`!<0@`)B$"&,4```%@#_]```````
M`(`ECYF!!`,@^`D"`"`E`B`@)8^\`"B/F8$$`R#X"0!`L"6/O``H`L*P(2;6
M!`2/F8$D`R#X"0+`("4D!O__C[P`*`!`("4`0)`EK[$`'"0%``&OL``0CY.`
M)(^"@"2/AX`DCYF`@"9S6V`D0ER().=<?*^S`!0#(/@)KZ(`&"0%`<"/O``H
MCYF`Z`,@^`D"0"`E)`/__Q1#``B/O``HCYF`X`,@^`D`````)`,`$8Q"```4
M0P$#C[P`*">C`""/F8"0/!'__S0"@5`F)G\8`$,0(20$``,`1C`A`R#X"0)`
M*"6/O``H$$``*@!`@"6/@H&,)`4``8^&@"0``(@ECYF`J(ZG``",1```),9<
MS`,@^`FOL@`0C[P`*">C`"`T`H%,`$,0(8^C`#B,1````B`0)8QC```4@P*T
MCYF!8">]`:B/OW_LC[Y_Z(^W?^2/MG_@C[5_W(^T?]B/LW_4C[)_T(^Q?\R/
ML'_(`^``"">]?_"/F8&``R#X"0(`("6/O``H$$#_B`!`@"40`/^>CYF!!">C
M`"`T`H%0`$,0(20#0```4;@ACN)_,#!"\``40__0CX*!C(^9@5P#(/@)COY_
M.!?"_\J/O``HCN)_,"0#`<`P0@'_%$/_QH^"@8R/F8$D`R#X"0+`("4F)7[D
MC[P`*">C`"``0(@E-`*!4`*`R"6/A(`D`$,0(0!%*"$$$?F#)(1=(!!``,*/
MO``HCYF!@`!`("4#(/@)CK0``(^\`"@"@"`ECYF`1`01_%4`0"@EC[P`*!!`
M`+8`0*`ECYF!!`,@^`D"@"`E`$"P)2Q"``040``0C[P`*(^%@"0FQ/_\CYF!
MH`*$("$#(/@))*5=*!1```B/O``H)`(`!!+"`AD"EK`A)`(`+X+#__L08@(5
M`````(^9@$@$$?X*`````!1```B/O``HCYF`_```*"4#(/@)`H`@)8^\`"@4
M0`"6KZ(`0(^%@"0D%O__CX2`)"07`!&/@H`D)*5<,"2$6Z@D62X@!!'YW@,@
M\"6/O``HCYF!,`,@^`D`````)`;__X^\`"@D!0`!`B`@):^B`!BOLP`4K[(`
M$(^4@"2/AX`DCYF`@":47@@DYUU(`R#X":^T`!R/O``HCY6`)!```!<FM5U8
MCYF`X`,@^`D`````C$(``!17`!>/O``HCYF!,`,@^`DF$``!)`;__X^\`"@D
M!0`!K[0`(`*@."6OL``<`B`@):^B`!BOLP`4CYF`@`,@^`FOL@`0C[P`*(^9
M@.@D!0'``R#X"0(@("405O_EC[P`*(^9@80#(/@)`D`@)0(@*"6/H@`\`\#(
M)0,@^`DD1%LXC[P`*(^9@#P$$?WZ`B`@)1``_TB/O``H/!/__S0"@5`GHP`@
M)G=^Y`!#$"$``/`E)G9^]`!7N"$"("`E-`*!4">C`"``0Q`A$(``#P!6B"$"
M@,@E!!'X^`+@*"4GW@`!$$``!(^\`"B`0P``%&``#H^9@8``'A"``B(0(8Q$
M```4@/_T`H#()8^9@20#(/@))`0`#8^\`"@`0(@ECY*`)!``_HDF4EQ,`R#X
M"0!`("6/O``H%$#^>`!`D"4GI``@-`*!4``>&(``1!`A`%,0(0!#$"$0`/_9
MC$1^](^#@8PD!0`!CX:`)```B"6/F8"HCJ<``(QD```DQER0KZ(`%`,@^`FO
ML@`0$`#_"H^\`"@`0"`E!!']MZ^B`#2/O``HCZ(`-(^9@8`#(/@)`$`@)8^\
M`"@0`/[_`$"()1``_TJ.M```CYF!-"06``(D!__N)`;__Z^V`!``0"`E`R#X
M"0!`J"6/O``H)Z,`(#P0__\T`H%0)A1__`!#$"&/F8&8)`8`!@!4H"$"H"`E
M`R#X"0*`*"4T`H%0)Z,`(`!#$"$`4(`AD@)__!1```6/O``HD@)__20#`$,0
M0P%T)`,`08^9@30``#@ECZ0`0```,"4#(/@)KZ``$">D`"`T`X%0C[P`*#P"
M__\`9!@A)$I__"1)?Q@`8A`A-`.!4#P%9T4`9!@AK$!_D#2E(P$`:J@AK$5_
M'#0#@5`\!>_-K[4`3`!D&"$TI:N)```@):Q%?R0\!9BZK$1_&```("4TI=S^
MK$1_(```("6L17\L/`40,@!IL"&L1'\HCX.`)#2E5'8``"`EK$5_-#P%P](D
M8QD@K$1_,```("4TI>'PKZ,`-*Q%?SPFPP`X```H):Q$?S@``"`EKZ,`1`!`
M\"6L17]$K$1_0*Q%?TRL1'](CYF!F#0&@`"/I`!``R#X"0*@*"6/O``H&$``
M8P!`N"6/PG]$`!<PP(_#?T``%R_#C\=_2`#","$48``$C\1_3`#"$"L00``&
M``58P"2"``$`1"`K`(<X(0!`("4`!5C`C\)_D``7'T*OP']```4O0J_&?T0!
M8Q@E`&0@(0"G*"$`@Q@KK\1_3`!E&"$00`!$K\-_2"00`$"/HP!$CYF!?`("
MH"./I0!,`&(@(0*7$"H"XJ`*`R#X"0*`,"6/PG^0C[P`*`*"$"$44/_-K\)_
MD(^Y`#0"P"`E`R#X"0+TN"./H@!,C[P`*`!4@"$JXP!`%&``(@(`H"4F]__`
M`!<1@B14``&OH@!(`!2A@`(4H"$GPW]0)@L`0`(`$"6(1P``)&,`$(A&``2(
M10`(B$0`#)A'``.81@`'F$4`"YA$``\D0@`0K&?_\*QF__2L9?_X%$O_\JQD
M__R/N0`T`L`@)0,@^`D`0(`E%I#_Z8^\`"B/H@!(``*!@`+PN"./F8$<)`<`
M2(^D`$0"X#`E`R#X"0*`*"6/O``H$`#_F:_7?Y`0`/_2`J"`)8^9@(P#(/@)
MCZ0`0">C`"`T`H%0C[P`*">E`"``0Q`A/`/__P!#$"$`8#`EC%5_1(Q7?TPT
M`H%0?J0HP`!%$"$D!?^``$00(22$``$`8A`A*(,`.11@`*J@17]0)Z,`((^9
M@.PT`H%0)-1_&`!#$"$D!@!``%2@(0#$,",FD``X```H)0,@^`D"!"`AC[D`
M-`,@^`D"@"`EKH``.*Z``#RN@`!`KH``1*Z``$BN@`!,KH``4*Z``%2N@`!8
MKH``7*Z``&"N@`!DKH``:*Z``&PGHP`@C[D`-#0"@5`\%/__`$,0(0`7.@(`
M5!@A)Z@`(``7+@*OHP!`H&=_BC0'@5``%Q0"H&5_B`#H."&@=W^+)H1_&*!B
M?XD`%38"H'5_CP`5+`(`%1("H&9_C`#D("&@97^-H&)_C@,@^`DFD'_0)Z0`
M((^C`$`T`H%0C[P`*`!$$"&,:'\<`%2@(30"@5",9W\DC&9_+":4?[T`1!`A
MC&5_-``(5`*,9'\\``A*`H^6@"0`!V8"H&I_O0`'7`*@:7^^``=2`J!H?[\`
M4(`AH&Q_P``(%@*@:W_!``9.`J!J?\(`!D0"H&=_PP`&:@*@:7_$``5F`J!H
M?\4`!5P"H&)_O``%4@*@;7_&``1.`J!F?\<`!$0"H&Q_R``$.@*@:W_))A<`
M**!J?\HFUEQTH&5_RZ!I?\R@:'_-H&=_SA````.@9'_/DH(``":4``&/F8"`
M`@`@)20&__^OH@`0)`4``280``(#(/@)`L`X)1;P__6/O``H)Z4`((^'@"0T
M!(%0CYF`@#P"__^OLP`4`(4@(:^R`!`D0W_0`((0(30$@5`D!O__`(4@(23G
M73@`@Q@ACX2`)"0%``&OHP`8)(1>"*^D`!P"("`EH$!_^`,@^`D`````C[P`
M*(^"@"0D0BX@$`#^-0!`\"6.M0`$$J#]ZH^9@00#(/@)`J`@)2Q#``048/WE
MC[P`*(^%@"0D0O_\CYF!H`*B("$#(/@))*5=,(^\`"@0`/W<`J*@"B>C`""/
MF8#L-`*!4"0&`#@`0Q`A/`/__P#$,",`0Q`A```H)21"?U`#(/@)`$0@(1``
M_V@GHP`@D@1__A2#_HR/F8$TD@-__Q1B_HH``#@EDZ,!<"0"`$@48OZ&DZ,!
M<20"`$448OZ#)`;__X^P`$`D!__&K[8`$`,@^`D"`"`E)`8`*8^\`"@"@"@E
MCYF!F`,@^`D"`"`E)`;__X^\`"@D!0`!`B`@):^T`!BOLP`4K[(`$(^"@"2/
MAX`DCYF`@"1"7@@DYUTX$`#_M:^B`!P#(/@)`````#P<``(GG-!P`YG@(2>]
M_Z"/@H%XCYF`E*^Q`#ROOP!<K[P`$*^R`$`GL@`PK[``.*^^`%BOMP!4K[8`
M4*^U`$ROM`!(K[,`1*^B`"R/D8%8C$(``*^R`"2OH@`T`R#X"8XD``"/O``0
M`$"`)8^9@)0#(/@)CB0```)`*"6/O``0D@,`:(^&@"2/A(`DH$,`:239*\PD
MA%N,!!'VW*^Y`"@00``%C[P`$(!$```D`P`Q$(,`_@````"/F8!,!!'ZS0``
M``"/O``0CYF`E`,@^`F.)```)`<`"X^\`!`D!@`!`$`@)8^%@"2/F8$@`R#X
M"22E76P00`#KC[P`$(^3@"B,1``0CCX``(YBL?@H0@`"%$``0XR4`!@\%0`@
MCY>`*```D"4D$``!)K4$`!````PD%@0`CYF!H`$@("4#(/@)C,4`$(^\`!`4
M0``RCF2Q^"80``$"!!`J$$``+B92``&/F8"4`R#X"0/`("4``#@EC[P`$`)`
M,"4"@"@ECYF`O`,@^`D`0"`EC[P`$!!``,P`0$`EC$8````0((".Y;'TCCX`
M`(S"``@`I"`A`%40)!!6_^",B0``CYF`E`/`("6OJ0`<`R#X":^H`"`D!P`"
MC[P`$```,"6/J``@`$`@)8^9@4`#(/@)C04``(^\`!``0"@ECZD`'(X^``"/
MF8&@`R#X"0$@("6/O``0$$#_T(YDL?@D@O__$%(`@RB$``*/F8"4`R#X"0/`
M("4D!P`#C[P`$"0&``$`0"`ECX6`)(^9@2`#(/@))*5==(^\`!`00``2`$"`
M)8^9@)0#(/@)CB0``(^\`!``0"`EC@,`$(^&@"2/F8%$C&4```,@^`DDQEUX
MC@(`$(Q"``",0@`(?$(%@!1``)V/O``0CYF`E`,@^`F.)```)`<``X^\`!`D
M!@`!`$`@)8^%@"2/F8$@`R#X"22E78"/O``0$$``%0!`@"6/A(`DC[D`*(^E
M`"0#(/@))(1;1(^\`!``0)`ECB0``!!``'B/F8"4`R#X"0`````"0#`EC[P`
M$`!`("6.`P`0CYF!1`,@^`F,90``C[P`$(^9@)2/DH`H`R#X"8XD``"/O``0
M`$"`)8^9@)0#(/@)CB0``"0&``&/O``0`$`@)8^%@"2/F8#X`R#X"22E780"
M`"`EC[P`$`!`*"6/AH`DCYF!1`,@^`DDQEV<C[P`$(^9@)0#(/@)CB0``(^\
M`!"/I0`DC[D`**!``&F/A(`D`R#X"22$6SB/O``0`$"`)1!``"^N0K'\CYF`
MZ"0%`<`#(/@)`@`@)20#`!$00P`%C[P`$"1#``$L8P`"$&``6`!`."6/H@`L
MCZ,`-(Q"```48@!0C[\`7(^^`%B/MP!4C[8`4(^U`$R/M`!(C[,`1(^R`$"/
ML0`\C[``.`/@``@GO0!@%(#_?H^9@)0D$``!CYF`E`/`("4#(/@))A```0*`
M*"6/O``0CYF!=`,@^`D`0"`ECF*Q^(^\`!`"`A`J%$#_\XX^```0`/]MCYF`
ME(^"@"B/F8!0!!'[*HQ$L?2/O``0`$"`)11`_\NN0K'\CX2`)(^9@/0#(/@)
M)(1=I!``_UZ./@``@$(``1!`_P6/F8!,$`#_``````".9+'X)(+__Q12_U6.
M/@``$`#_U2B$``(#(/@)`````(^\`!".`P`0CX*`*(^9@"2,9```C$*Q]"<Y
M,]0$$??%C$4``!``_X>/O``0CYF`E`,@^`F.)```C[P`$`!`("6.`P`0CYF`
MU`,@^`F,90``$`#_6H^\`!"/F8%@`R#X"0````"/@H`HCX2`)`(`,"6/F8#T
MC$*Q]"2$7<@#(/@)C$4``#P<``(GG,L,`YG@(2>]_]B/F8!4K[P`$*^Q`""O
ML``<K[\`)`01^3D`@(@E@$,```!`@"408``'C[P`$"1"``$X8P`O`$.`"H!#
M```48/_\)$(``8^9@$@$$?I!`````!!```V/O``0$B``#(^_`"2"(@``$$``
M"20&``2/A8`DCYF`H`(`("4#(/@))*5<B!!```:/O``0C[\`)(^Q`""/L``<
M`^``"">]`"B/F8`D`B`@)8^_`"2/L0`@C[``'"<Y,/00`/;")[T`*#P<``(G
MG,I``YG@(8^"@&B/F8$X`R``"(Q'````````/!P``B><RB`#F>`A)[W_R(^9
M@&ROO``0K[4`,`#`J"6OM``L`*"@):^S`"@`@)@EK[(`)*^P`!ROOP`T!!'O
MB*^Q`""/O``0CY"`<(^2@'0"4)`C`!*0@Q)```D``(@ECAD``"8Q``$"H#`E
M`H`H)0,@^`D"8"`E%E'_^280``2/OP`TC[4`,(^T`"R/LP`HC[(`)(^Q`""/
ML``<`^``"">]`#@#X``(``````````"/F8`0`^!X)0,@^`DD&`!LCYF`$`/@
M>"4#(/@))!@`:X^9@!`#X'@E`R#X"208`&F/F8`0`^!X)0,@^`DD&`!GCYF`
M$`/@>"4#(/@))!@`98^9@!`#X'@E`R#X"208`&2/F8`0`^!X)0,@^`DD&`!C
MCYF`$`/@>"4#(/@))!@`8H^9@!`#X'@E`R#X"208`&"/F8`0`^!X)0,@^`DD
M&`!>CYF`$`/@>"4#(/@))!@`78^9@!`#X'@E`R#X"208`%R/F8`0`^!X)0,@
M^`DD&`!;CYF`$`/@>"4#(/@))!@`6H^9@!`#X'@E`R#X"208`%B/F8`0`^!X
M)0,@^`DD&`!7CYF`$`/@>"4#(/@))!@`58^9@!`#X'@E`R#X"208`%2/F8`0
M`^!X)0,@^`DD&`!3CYF`$`/@>"4#(/@))!@`4H^9@!`#X'@E`R#X"208`%&/
MF8`0`^!X)0,@^`DD&`!0CYF`$`/@>"4#(/@))!@`3X^9@!`#X'@E`R#X"208
M`$Z/F8`0`^!X)0,@^`DD&`!-CYF`$`/@>"4#(/@))!@`3(^9@!`#X'@E`R#X
M"208`$N/F8`0`^!X)0,@^`DD&`!*CYF`$`/@>"4#(/@))!@`2(^9@!`#X'@E
M`R#X"208`$:/F8`0`^!X)0,@^`DD&`!%CYF`$`/@>"4#(/@))!@`1(^9@!`#
MX'@E`R#X"208`$./F8`0`^!X)0,@^`DD&`!"CYF`$`/@>"4#(/@))!@`08^9
M@!`#X'@E`R#X"208`$"/F8`0`^!X)0,@^`DD&``_CYF`$`/@>"4#(/@))!@`
M/H^9@!`#X'@E`R#X"208`#V/F8`0`^!X)0,@^`DD&``[CYF`$`/@>"4#(/@)
M)!@`.H^9@!`#X'@E`R#X"208`#F/F8`0`^!X)0,@^`DD&``XCYF`$`/@>"4#
M(/@))!@`-X^9@!`#X'@E`R#X"208`#:/F8`0`^!X)0,@^`DD&``UCYF`$`/@
M>"4#(/@))!@`-(^9@!`#X'@E`R#X"208`#./F8`0`^!X)0,@^`DD&``RCYF`
M$`/@>"4#(/@))!@`,(^9@!`#X'@E`R#X"208`"^/F8`0`^!X)0,@^`DD&``N
MCYF`$`/@>"4#(/@))!@`+8^9@!`#X'@E`R#X"208`"N/F8`0`^!X)0,@^`DD
M&``ICYF`$`/@>"4#(/@))!@`*(^9@!`#X'@E`R#X"208`">/F8`0`^!X)0,@
M^`DD&``FCYF`$`/@>"4#(/@))!@`)8^9@!`#X'@E`R#X"208`"2/F8`0`^!X
M)0,@^`DD&``C`````````````````````#P<``(GG,60`YG@(2>]_^"OO``0
MK[\`'(^_`!P#X``()[T`(``````````````````"``$N````+BX``"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%2
M7U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),
M-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!
M4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$
M25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@````!005)?0TQ%04X]```Q````3$1?3$E"4D%265]0051(`%5315(`
M````4UE35$5-```O=&UP`````%1%35!$25(`5$U0`%5315).04U%`````"4P
M,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A
M<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P``
M`"5S)7-T96UP+25U+25U)7,`````05)'5@`````8````<&5R;``````P````
M4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-#<```!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`"UE```M+0``979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP
M86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H
M*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O
M<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@
M)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H
M:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4[
M"G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@
M;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B
M=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE
M(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E
M>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D
M;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F
M<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]
M("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D
M8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@
M)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*
M)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E]
M(&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI
M.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R
M96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO
M9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@
M*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@
M)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E
M(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM0
M05)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`]
M(&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H
M)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A
M(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O
M;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E
M*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q0
M05(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F
M:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[
M)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>
M6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@
M(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@
M)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^
M<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H
M)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;
M7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S
M=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@
M(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO
M=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII
M9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE
M;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E
M;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%
M/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP
M<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M
M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B
M*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F
M:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D
M>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT
M<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC
M871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF
M("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613
M:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC
M92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E
M('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S
M=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI
M8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@
M<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R
M"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF
M="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H
M+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G
M7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*
M<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@
M<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I
M<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E
M<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q
M=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O
M;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH
M(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E
M:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D
M8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L
M<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI
M('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F
M:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N
M("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E
M*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L
M("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R
M7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M
M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E
M;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I
M;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS:2YC````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````!D````8E`````````````````````#_____``````````````````!>
M%```````````````````````````````````````````@```````%+```%80
M``!6M````````@````$`````-3P``$_````V&```/X@``#\T```W0```/H0`
M`#NT``!`Z```.C```%7P``&@(```520``:`T``&AV```%'```9_X``&?_```
M``````````!:@```6G```%I@``!:4```6D```%HP``!:(````````%H0````
M````6@```%GP``!9X```6=````````!9P```6;```%F@``!9D```68```%EP
M``!98```65```%E```!9,````````%D@``!9$```60```%CP``!8X```6-``
M`%C```!8L```6*```%B0````````6(````````!8<```6&```%A0``!80```
M6#```%@@``!8$```6````%?P``!7X```5]```%?`````````5[```%>@````
M````5Y```%>```!7<```5V```%=0````````5T````````!7,```5R```%<0
M``!7`````````%;P````````5N````````!6T```5L```:'81T-#.B`H1&5B
M:6%N(#@N,BXP+3$P*2`X+C(N,`!'0T,Z("A$96)I86X@-RXS+C`M,CDI(#<N
M,RXP```````9((`#``#____\``````````````*P````'0```!\``"O,@'\`
M`/____P``````````````#@````=````'P``+4"`'P``_____```````````
M````.````!T````?```N((#_``#____\``````````````!(````'0```!\`
M`##TP/\``/____P``````````````/@````=````'P``,QR``P``_____```
M````````````T````!T````?```SU(`_``#____\`````````````!!`````
M'0```!\``#4\@````/____P``````````````"`````=````'P``-9"``0``
M_____```````````````*````!T````?```V&(`'``#____\````````````
M`"!`````'0```!\``#<H```````````````````````````````=````'P``
M-T#`_P``_____``````````````1"````!T````?```Z!```````````````
M````````````````'0```!\``#HP@`,``/____P``````````````"@````=
M````'P``.[2`?P``_____```````````````:````!T````?```^A(`#``#_
M___\```````````````P````'0```!\``#\T@````/____P`````````````
M`"`````=````'P``/XB`'P``_____```````````````2````!T````?``!`
MZ,#_``#____\`````````````(&8````'0```!\``$_`P/\``/____P`````
M`````````&`````=````'P``522``P``_____```````````````*````!T`
M```?```4L(`_``#____\``````````````!0````'0```!\``%7P````````
M```````````````````````=````'P``5A"`/P``_____```````````````
M.````!T````?``!6M```````````````````````````````'0```!]!````
M#V=N=0`!````!P0%`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+DU)4%,N86)I9FQA9W,`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD+6ED`"YD
M>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`
M+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=``N
M<&1R`"YG;G4N871T<FEB=71E<P`N;61E8G5G+F%B:3,R````````````````
M```````````````````````````````````````````+`````0````(```&4
M```!E`````T```````````````$`````````$P````<````"```!I````:0`
M```@```````````````$`````````"%P```J`````@```<@```'(````&```
M````````````"````!@````P<```!@````(```'@```!X````!@`````````
M``````0````8````.0````<````"```!^````?@````D```````````````$
M`````````$P````&`````@```AP```(<```!4`````D`````````!`````@`
M``!5````!0````(```-L```#;````T`````(``````````0````$````6P``
M``L````"```&K```!JP```;0````"0````(````$````$````&,````#````
M`@``#7P```U\```%00```````````````0````````!K;____P````(``!*^
M```2O@```-H````(``````````(````"````>&____X````"```3F```$Y@`
M``"P````"0````,````$`````````(<````)`````@``%$@``!1(````*```
M``@`````````!`````@```"0`````0````8``!1P```4<````#P`````````
M``````0`````````E@````$````&```4L```%+```$(0```````````````0
M`````````)P````!````!@``5L```%;````#X```````````````!```````
M``"H`````0````8``%J@``!:H````"0```````````````0`````````K@``
M``$````"``!:T```6M```#^P```````````````0`````````+8````!````
M`@``FH```)J`````!```````````````!`````````#`````#@````,``9_X
M``"?^`````0```````````````0````$````S`````\````#``&?_```G_P`
M```$```````````````$````!````-@````!`````P`!H````*``````,```
M````````````$`````````#>`````0````,``:`P``"@,`````0`````````
M``````0`````````YP````$0```#``&@0```H$````&8```````````````0
M````!````.P````!$````P`!H=@``*'8````!```````````````!```````
M``#S````"`````,``:'@``"AW```$#```````````````!``````````^```
M``$````P````````H=P````Z```````````````!`````0```0$````!````
M`````````*(8```#(```````````````!`````````$&;___]0``````````
M``"E.````!````````````````$````````!%@````$`````````````I4@`
M```````````````````!``````````$````#`````````````*5(```!)```
.`````````````0``````
